@@ -1,5 +1,6 @@
-'''
-This file is forked from https://github.com/tensorflow/tensorboard/blob/master/tensorboard/compat/tensorflow_stub/io/gfile.py.
+"""
+This file is forked from
+https://github.com/tensorflow/tensorboard/blob/master/tensorboard/compat/tensorflow_stub/io/gfile.py.
 The following functionalities are added after forking:
 * Check Azure Blob & Google Cloud available or not
 * get_filesystem changes to support Azure Blobs
@@ -11,7 +12,7 @@ The following functionalities are added after forking:
 * add specialized walk for Local file system, Azure Blob and Google Cloud to improve the walk performance.
 * add global wrapper for abspath, basename, join, download_file.
 * change the global walk wrapper to support specialized walk.
-'''
+"""
 import glob as py_glob
 import os
 import tempfile
@@ -165,6 +166,7 @@ class LocalFileSystem(LocalPath, BaseFileSystem):
         # [1] https://github.com/tensorflow/tensorboard/blob/master/README.md#logdir--logdir_spec-legacy-mode
         yield from os.walk(top, topdown, onerror, followlinks=True)
 
+
 class S3FileSystem(RemotePath, BaseFileSystem):
     """Provides filesystem access to S3."""
 
@@ -256,22 +258,17 @@ class S3FileSystem(RemotePath, BaseFileSystem):
             file_content = as_bytes(file_content)
         client.put_object(Body=file_content, Bucket=bucket, Key=path)
 
-    def download_file(self, filename):
-        fp = tempfile.NamedTemporaryFile(
-            'w+t', suffix='.%s' % self.basename(filename), delete=False)
-        fp.close()
-
+    def download_file(self, file_to_download, file_to_save):
         logger.info("s3: starting downloading file %s as %s" %
-                    (filename, fp.name))
+                    (file_to_download, file_to_save))
         # Use boto3.resource instead of boto3.client('s3') to support minio.
         # https://docs.min.io/docs/how-to-use-aws-sdk-for-python-with-minio-server.html
         # To support minio, the S3_ENDPOINT need to be set like: S3_ENDPOINT=http://localhost:9000
         s3 = boto3.resource("s3", endpoint_url=self._s3_endpoint)
-        bucket, path = self.bucket_and_path(filename)
-        s3.Bucket(bucket).download_file(path, fp.name)
-        logger.info("s3: file %s is downloaded as %s" %
-                        (filename, fp.name))
-        return fp.name
+        bucket, path = self.bucket_and_path(file_to_download)
+        s3.Bucket(bucket).download_file(path, file_to_save)
+        logger.info("s3: file %s is downloaded as %s" % (file_to_download, file_to_save))
+        return
 
     def glob(self, filename):
         """Returns a list of files that match the given pattern(s)."""
@@ -355,6 +352,7 @@ if GS_ENABLED:
     from .gs import GoogleBlobSystem
     register_filesystem("gs", GoogleBlobSystem())
 
+
 class File(object):
     def __init__(self, filename, mode):
         if mode not in ("r", "rb", "br", "w", "wb", "bw"):
@@ -388,7 +386,7 @@ class File(object):
         old_buff_offset = self.buff_offset
         read_size = min(len(self.buff), new_buff_offset) - old_buff_offset
         self.buff_offset += read_size
-        return self.buff[old_buff_offset : old_buff_offset + read_size]
+        return self.buff[old_buff_offset: old_buff_offset + read_size]
 
     def read(self, n=None):
         """Reads contents of file to a string.
@@ -418,7 +416,8 @@ class File(object):
 
         # read from filesystem
         read_size = max(self.buff_chunk_size, n) if n is not None else None
-        (self.buff, self.continuation_token) = self.fs.read(self.filename, self.binary_mode, read_size, self.continuation_token)
+        (self.buff, self.continuation_token) = self.fs.read(
+            self.filename, self.binary_mode, read_size, self.continuation_token)
         self.buff_offset = 0
 
         # add from filesystem
@@ -515,30 +514,43 @@ def exists(filename):
     """Determines whether a path exists or not."""
     return get_filesystem(filename).exists(filename)
 
+
 def abspath(path):
     return get_filesystem(path).abspath(path)
 
+
 def basename(path):
     return get_filesystem(path).basename(path)
 
+
 def relpath(path, start):
     return get_filesystem(path).relpath(path, start)
 
+
 def join(path, *paths):
     return get_filesystem(path).join(path, *paths)
 
-def download_file(filename):
+
+def download_file(file_to_download, file_to_save):
     """Downloads the file, returning a temporary path to the file after finishing."""
-    return get_filesystem(filename).download_file(filename)
+    get_filesystem(file_to_download).download_file(file_to_download, file_to_save)
+
 
 def glob(filename):
     """Returns a list of files that match the given pattern(s)."""
     return get_filesystem(filename).glob(filename)
 
+
+def is_local(path):
+    """Returns whether the path is a local path"""
+    return isinstance(get_filesystem(path), LocalFileSystem)
+
+
 def isdir(dirname):
     """Returns whether the path is a directory or not."""
     return get_filesystem(dirname).isdir(dirname)
 
+
 def listdir(dirname):
     """Returns a list of entries contained within a directory.
 
@@ -547,10 +559,12 @@ def listdir(dirname):
     """
     return get_filesystem(dirname).listdir(dirname)
 
+
 def makedirs(path):
     """Creates a directory and all parent/intermediate directories."""
     return get_filesystem(path).makedirs(path)
 
+
 def walk(top, topdown=True, onerror=None):
     """Recursive directory tree generator for directories.
 
@@ -597,10 +611,12 @@ def walk(top, topdown=True, onerror=None):
         if not topdown:
             yield here
 
+
 def stat(filename):
     """Returns file statistics for a given path."""
     return get_filesystem(filename).stat(filename)
 
+
 def read(file):
     with File(file, 'rb') as f:
         return f.read()
